@@ -2,7 +2,7 @@
  * FileSystem.cs - Implementation of the
  *			"Microsoft.VisualBasic.FileSystem" class.
  *
- * Copyright (C) 2003  Southern Storm Software, Pty Ltd.
+ * Copyright (C) 2003, 2004  Southern Storm Software, Pty Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -762,20 +762,20 @@ public sealed class FileSystem
 				byte[] buf = enc.GetBytes(Value);
 				file.stream.Write(buf, 0, nbytes);
 			}
-	[TODO]
+	[Obsolete("Use FilePutObject to write Object types, or coerce FileNumber and RecordNumber to Integer for writing non-Object types")]
 	public static void FilePut
 				(Object FileNumber, Object Value,
-			     [Optional] [DefaultValue(-1L)] long RecordNumber)
-			{
-				// TODO
-			}
-	[Obsolete("Use FilePut(Object, Object, long) instead")]
-	public static void FilePutObject
-				(int FileNumber, Object Value,
-			     [Optional] [DefaultValue(null)] Object RecordNumber)
+			     [Optional] [DefaultValue(-1L)] Object RecordNumber)
 			{
 				throw new ArgumentException(S._("VB_Obsolete"));
 			}
+	[TODO]
+	public static void FilePutObject
+				(int FileNumber, Object Value,
+			     [Optional] [DefaultValue(null)] long RecordNumber)
+			{
+				// TODO
+			}
 
 	// Set the record width for a file.
 	public static void FileWidth(int FileNumber, int RecordWidth)
@@ -908,24 +908,23 @@ public sealed class FileSystem
 			}
 
 	// Lock a record within a file.
-	[TODO]
 	public static void Lock(int FileNumber, long Record)
 			{
-				// TODO
+				Lock(FileNumber, Record, Record);
 			}
 
 	// Lock the entire contents of a file.
-	[TODO]
 	public static void Lock(int FileNumber)
 			{
-				// TODO
+				Lock(FileNumber, 1, Int64.MaxValue);
 			}
 
 	// Lock a region within a file.
-	[TODO]
 	public static void Lock(int FileNumber, long FromRecord, long ToRecord)
 			{
-				// TODO
+				File file = File.GetFile
+					(FileNumber, Assembly.GetCallingAssembly());
+				file.Lock(FromRecord, ToRecord);
 			}
 
 #if !ECMA_COMPAT
@@ -1163,18 +1162,18 @@ public sealed class FileSystem
 			}
 
 	// Seek to a new file position.
-	[TODO]
 	public static void Seek(int FileNumber, long Position)
 			{
-				// TODO
+				File file = File.GetFile
+					(FileNumber, Assembly.GetCallingAssembly());
+				file.SetRecord(Position);
 			}
 
 	// Get the current seek position within a file.
-	[TODO]
 	public static long Seek(int FileNumber)
 			{
-				// TODO
-				return 0;
+				return File.GetFile
+					(FileNumber, Assembly.GetCallingAssembly()).Location;
 			}
 
 #if !ECMA_COMPAT
@@ -1206,24 +1205,23 @@ public sealed class FileSystem
 			}
 
 	// Unlock a record within a file.
-	[TODO]
 	public static void Unlock(int FileNumber, long Record)
 			{
-				// TODO
+				Unlock(FileNumber, Record, Record);
 			}
 
 	// Unlock the entire contents of a file.
-	[TODO]
 	public static void Unlock(int FileNumber)
 			{
-				// TODO
+				Unlock(FileNumber, 1, Int64.MaxValue);
 			}
 
 	// Unlock a region within a file.
-	[TODO]
 	public static void Unlock(int FileNumber, long FromRecord, long ToRecord)
 			{
-				// TODO
+				File file = File.GetFile
+					(FileNumber, Assembly.GetCallingAssembly());
+				file.Unlock(FromRecord, ToRecord);
 			}
 
 	// Write data to a file.
