@@ -53,6 +53,7 @@ public class GlobalObject
 				AddBuiltin(inst, "encodeURIComponent");
 				AddBuiltin(inst, "escape");
 				AddBuiltin(inst, "eval");
+				AddBuiltin(inst, "GetObject");
 				AddBuiltin(inst, "isFinite");
 				AddBuiltin(inst, "isNaN");
 				AddBuiltin(inst, "parseFloat");
@@ -83,10 +84,8 @@ public class GlobalObject
 				AddProperty("EvalError", EvalError);
 #endif
 				AddProperty("Function", Function);
-#if false
 				AddProperty("Math", Math);
 				AddProperty("Number", Number);
-#endif
 				AddProperty("Object", Object);
 #if false
 				AddProperty("RangeError", RangeError);
@@ -179,23 +178,20 @@ public class GlobalObject
 					return EngineInstance.Default.GetFunctionConstructor();
 				}
 			}
-#if false
 	public static MathObject Math
 			{
 				get
 				{
-					// TODO
-					return null;
+					return new MathObject(EngineInstance.Default.GetObjectPrototype());
 				}
 			}
 	public static NumberConstructor Number
 			{
 				get
 				{
-					return NumberConstructor.constructor;
+					return EngineInstance.Default.GetNumberConstructor();
 				}
 			}
-#endif
 	public static ObjectConstructor Object
 			{
 				get
@@ -659,6 +655,13 @@ public class GlobalObject
 				// so this method should never be called.
 				throw new JScriptException(JSError.IllegalEval);
 			}
+			
+	// Gets an object
+	[JSFunction(0, JSBuiltin.Global_GetObject)]
+	public static object GetObject(object moniker, object progId)
+			{
+				throw new JScriptException(JSError.InvalidCall);
+			}
 
 	// Determine if a number is finite.
 	[JSFunction(0, JSBuiltin.Global_isFinite)]
@@ -983,6 +986,7 @@ public sealed class LenientGlobalObject : GlobalObject
 	public new object encodeURIComponent;
 	[NotRecommended("escape")] public new object escape;
 	public new object eval;
+	public new object GetObject;
 	public new object isFinite;
 	public new object isNaN;
 	public new object parseFloat;
@@ -1023,6 +1027,7 @@ public sealed class LenientGlobalObject : GlobalObject
 					globalObject.Get("encodeURIComponent");
 				escape = globalObject.Get("escape");
 				eval = globalObject.Get("eval");
+				GetObject = globalObject.Get("GetObject");
 				isFinite = globalObject.Get("isFinite");
 				isNaN = globalObject.Get("isNaN");
 				parseFloat = globalObject.Get("parseFloat");
@@ -1231,7 +1236,6 @@ public sealed class LenientGlobalObject : GlobalObject
 					}
 				}
 			}
-#if false
 	private object math;
 	public new object Math
 			{
@@ -1242,7 +1246,10 @@ public sealed class LenientGlobalObject : GlobalObject
 						if(math == null ||
 						   math is Missing)
 						{
-							math = GlobalObject.Math;
+							// should be thread safe to do this ?
+							return new LenientMathObject(
+								EngineInstance.Default.GetObjectPrototype(), 
+								EngineInstance.Default.GetFunctionPrototype());
 						}
 						return math;
 					}
@@ -1278,7 +1285,6 @@ public sealed class LenientGlobalObject : GlobalObject
 					}
 				}
 			}
-#endif
 	private object objectConstructor;
 	public new object Object
 			{
