@@ -22,6 +22,7 @@ namespace Microsoft.JScript
 {
 
 using System;
+using System.Globalization;
 
 public class JSParser
 {
@@ -174,17 +175,38 @@ public class JSParser
 	// Parse a numeric value from the scanner.
 	private Object NumericValue(String text)
 			{
-				// TODO: handle hex literals.
-				double value = Double.Parse(text);
-				if(value >= (double)(Int32.MinValue) &&
-				   value <= (double)(Int32.MaxValue) &&
-				   Math.Round(value) == value)
+				if(text.Length > 2 && text[1] == 'x' && text[0] == '0')
 				{
-					return (int)value;
+					long longValue = Int64.Parse(text.Substring(2), 
+												NumberStyles.HexNumber);
+				
+					if( longValue >= Int32.MinValue &&
+					    longValue <= Int32.MaxValue)
+					{
+						return (int)longValue;
+					}
+					
+					return longValue;
 				}
 				else
 				{
-					return value;
+					double value = Double.Parse(text);
+					if(value >= (double)(Int32.MinValue) &&
+					   value <= (double)(Int32.MaxValue) &&
+					   Math.Round(value) == value)
+					{
+						return (int)value;
+					}
+					else if(value >= (double)(Int64.MinValue) &&
+							value <= (double)(Int64.MaxValue) &&
+							Math.Round(value) == value)
+					{
+						return (long)value;
+					}
+					else
+					{
+						return value;
+					}
 				}
 			}
 
@@ -924,7 +946,7 @@ public class JSParser
 			{
 				JNode expr, expr2;
 				expr = EqualityExpression(noIn);
-				while(token == JSToken.LogicalOr)
+				while(token == JSToken.BitwiseAnd)
 				{
 					NextToken();
 					expr2 = EqualityExpression(noIn);
@@ -940,7 +962,7 @@ public class JSParser
 			{
 				JNode expr, expr2;
 				expr = BitwiseAndExpression(noIn);
-				while(token == JSToken.LogicalOr)
+				while(token == JSToken.BitwiseXor)
 				{
 					NextToken();
 					expr2 = BitwiseAndExpression(noIn);
@@ -956,7 +978,7 @@ public class JSParser
 			{
 				JNode expr, expr2;
 				expr = BitwiseXorExpression(noIn);
-				while(token == JSToken.LogicalOr)
+				while(token == JSToken.BitwiseOr)
 				{
 					NextToken();
 					expr2 = BitwiseXorExpression(noIn);
@@ -972,7 +994,7 @@ public class JSParser
 			{
 				JNode expr, expr2;
 				expr = BitwiseOrExpression(noIn);
-				while(token == JSToken.LogicalOr)
+				while(token == JSToken.LogicalAnd)
 				{
 					NextToken();
 					expr2 = BitwiseOrExpression(noIn);
@@ -1622,7 +1644,7 @@ public class JSParser
 							}
 							catchName = scanner.GetIdentifierName();
 							NextToken();
-							Expect(JSToken.LeftParen, "`)' expected");
+							Expect(JSToken.RightParen, "`)' expected");
 							catchClause = Block();
 						}
 						else if(token != JSToken.Finally)
