@@ -1,5 +1,7 @@
 // ZipFile.cs
+//
 // Copyright (C) 2001 Mike Krueger
+// Copyright (C) 2004 John Reilly
 //
 // This file was translated from java, it was part of the GNU Classpath
 // Copyright (C) 2001 Free Software Foundation, Inc.
@@ -53,34 +55,36 @@ namespace ICSharpCode.SharpZipLib.Zip
 	/// 
 	/// This class is thread safe:  You can open input streams for arbitrary
 	/// entries in different threads.
-	/// 
-	/// author of the original java version : Jochen Hoenicke
+	/// <br/>
+	/// <br/>Author of the original java version : Jochen Hoenicke
 	/// </summary>
 	/// <example>
+	/// <code>
 	/// using System;
 	/// using System.Text;
 	/// using System.Collections;
 	/// using System.IO;
 	/// 
-	/// using NZlib.Zip;
+	/// using ICSharpCode.SharpZipLib.Zip;
 	/// 
 	/// class MainClass
 	/// {
 	/// 	static public void Main(string[] args)
 	/// 	{
 	/// 		ZipFile zFile = new ZipFile(args[0]);
-	/// 		//Console.WriteLine("Listing of : " + zFile.Name);
-	/// 		//Console.WriteLine("");
-	/// 		//Console.WriteLine("Raw Size    Size      Date     Time     Name");
-	/// 		//Console.WriteLine("--------  --------  --------  ------  ---------");
+	/// 		Console.WriteLine("Listing of : " + zFile.Name);
+	/// 		Console.WriteLine("");
+	/// 		Console.WriteLine("Raw Size    Size      Date     Time     Name");
+	/// 		Console.WriteLine("--------  --------  --------  ------  ---------");
 	/// 		foreach (ZipEntry e in zFile) {
 	/// 			DateTime d = e.DateTime;
-	/// 			//Console.WriteLine("{0, -10}{1, -10}{2}  {3}   {4}", e.Size, e.CompressedSize,
+	/// 			Console.WriteLine("{0, -10}{1, -10}{2}  {3}   {4}", e.Size, e.CompressedSize,
 	/// 			                                                    d.ToString("dd-MM-yy"), d.ToString("t"),
 	/// 			                                                    e.Name);
 	/// 		}
 	/// 	}
 	/// }
+	/// </code>
 	/// </example>
 	public class ZipFile : IEnumerable
 	{
@@ -92,11 +96,11 @@ namespace ICSharpCode.SharpZipLib.Zip
 		/// <summary>
 		/// Opens a Zip file with the given name for reading.
 		/// </summary>
-		/// <exception name="System.IO.IOException">
-		/// IOException if a i/o error occured.
+		/// <exception cref="IOException">
+		/// An i/o error occurs
 		/// </exception>
-		/// <exception name="ICSharpCode.SharpZipLib.ZipException">
-		/// if the file doesn't contain a valid zip archive.
+		/// <exception cref="ZipException">
+		/// The file doesn't contain a valid zip archive.
 		/// </exception>
 		public ZipFile(string name) : this(File.OpenRead(name))
 		{
@@ -105,29 +109,28 @@ namespace ICSharpCode.SharpZipLib.Zip
 		/// <summary>
 		/// Opens a Zip file reading the given FileStream
 		/// </summary>
-		/// <exception name="System.IO.IOException">
-		/// IOException if a i/o error occured.
+		/// <exception cref="IOException">
+		/// An i/o error occurs.
 		/// </exception>
-		/// <exception name="ICSharpCode.SharpZipLib.ZipException">
-		/// if the file doesn't contain a valid zip archive.
+		/// <exception cref="ZipException">
+		/// The file doesn't contain a valid zip archive.
 		/// </exception>
 		public ZipFile(FileStream file)
 		{
 			this.baseStream  = file;
-		#if !ECMA_COMPAT
 			this.name = file.Name;
-		#endif
 			ReadEntries();
 		}
 		
 		/// <summary>
 		/// Opens a Zip file reading the given Stream
 		/// </summary>
-		/// <exception name="System.IO.IOException">
-		/// IOException if a i/o error occured.
+		/// <exception cref="IOException">
+		/// An i/o error occurs
 		/// </exception>
-		/// <exception name="ICSharpCode.SharpZipLib.ZipException">
-		/// if the file doesn't contain a valid zip archive.
+		/// <exception cref="ZipException">
+		/// The file doesn't contain a valid zip archive.<br/>
+		/// The stream provided cannot seek
 		/// </exception>
 		public ZipFile(Stream baseStream)
 		{
@@ -140,11 +143,11 @@ namespace ICSharpCode.SharpZipLib.Zip
 		/// <summary>
 		/// Read an unsigned short in little endian byte order.
 		/// </summary>
-		/// <exception name="System.IO.IOException">
-		/// if a i/o error occured.
+		/// <exception cref="IOException">
+		/// An i/o error occurs.
 		/// </exception>
-		/// <exception name="System.IO.EndOfStreamException">
-		/// if the file ends prematurely
+		/// <exception cref="EndOfStreamException">
+		/// The file ends prematurely
 		/// </exception>
 		int ReadLeShort()
 		{
@@ -154,11 +157,11 @@ namespace ICSharpCode.SharpZipLib.Zip
 		/// <summary>
 		/// Read an int in little endian byte order.
 		/// </summary>
-		/// <exception name="System.IO.IOException">
-		/// if a i/o error occured.
+		/// <exception cref="IOException">
+		/// An i/o error occurs.
 		/// </exception>
-		/// <exception name="System.IO.EndOfStreamException">
-		/// if the file ends prematurely
+		/// <exception cref="System.IO.EndOfStreamException">
+		/// The file ends prematurely
 		/// </exception>
 		int ReadLeInt()
 		{
@@ -166,115 +169,126 @@ namespace ICSharpCode.SharpZipLib.Zip
 		}
 		
 		/// <summary>
-		/// Read the central directory of a zip file and fill the entries
+		/// Search for and read the central directory of a zip file filling the entries
 		/// array.  This is called exactly once by the constructors.
 		/// </summary>
-		/// <exception name="System.IO.IOException">
-		/// if a i/o error occured.
+		/// <exception cref="System.IO.IOException">
+		/// An i/o error occurs.
 		/// </exception>
-		/// <exception name="ICSharpCode.SharpZipLib.ZipException">
-		/// if the central directory is malformed
+		/// <exception cref="ICSharpCode.SharpZipLib.ZipException">
+		/// The central directory is malformed or cannot be found
 		/// </exception>
 		void ReadEntries()
 		{
-			/* Search for the End Of Central Directory.  When a zip comment is
-			* present the directory may start earlier.
-			* FIXME: This searches the whole file in a very slow manner if the
-			* file isn't a zip file.
-			*/
+			// Search for the End Of Central Directory.  When a zip comment is
+			// present the directory may start earlier.
+			// 
+			// TODO: The search is limited to 64K which is the maximum size of a trailing comment field to aid speed.
+			// This should be compatible with both SFX and ZIP files but has only been tested for Zip files
+			// Need to confirm this is valid in all cases.
+			// Could also speed this up by reading memory in larger blocks?
+			
+
+			if (baseStream.CanSeek == false) {
+				throw new ZipException("ZipFile stream must be seekable");
+			}
+
 			long pos = baseStream.Length - ZipConstants.ENDHDR;
+			if (pos <= 0) {
+				throw new ZipException("File is too small to be a Zip file");
+			}
+
+			long giveUpMarker = Math.Max(pos - 0x10000, 0);
+			
 			do {
-				if (pos < 0) {
+				if (pos < giveUpMarker) {
 					throw new ZipException("central directory not found, probably not a zip file");
 				}
 				baseStream.Seek(pos--, SeekOrigin.Begin);
 			} while (ReadLeInt() != ZipConstants.ENDSIG);
 			
-			long oldPos = baseStream.Position;
-			baseStream.Position += ZipConstants.ENDTOT - ZipConstants.ENDNRD;
+			int thisDiskNumber            = ReadLeShort();
+			int startCentralDirDisk       = ReadLeShort();
+			int entriesForThisDisk        = ReadLeShort();
+			int entriesForWholeCentralDir = ReadLeShort();
+			int centralDirSize            = ReadLeInt();
+			int offsetOfCentralDir        = ReadLeInt();
+			int commentSize               = ReadLeShort();
 			
-			if (baseStream.Position - oldPos != ZipConstants.ENDTOT - ZipConstants.ENDNRD) {
-				throw new EndOfStreamException();
-			}
-			int count = ReadLeShort();
-			
-			oldPos = baseStream.Position;
-			baseStream.Position += ZipConstants.ENDOFF - ZipConstants.ENDSIZ;
-			
-			if (baseStream.Position - oldPos != ZipConstants.ENDOFF - ZipConstants.ENDSIZ) {
-				throw new EndOfStreamException();
-			}
-			
-			int centralOffset = ReadLeInt();
-			
-			// GET COMMENT SIZE (COMES AFTER CENTRALOFFSET) 
-			int commentSize = ReadLeShort(); 
 			byte[] zipComment = new byte[commentSize]; 
 			baseStream.Read(zipComment, 0, zipComment.Length); 
 			comment = ZipConstants.ConvertToString(zipComment); 
 			
-			entries = new ZipEntry[count];
-			baseStream.Seek(centralOffset, SeekOrigin.Begin);
-			for (int i = 0; i < count; i++) {
+/* Its seems possible that this is too strict, more digging required.
+			if (thisDiskNumber != 0 || startCentralDirDisk != 0 || entriesForThisDisk != entriesForWholeCentralDir) {
+				throw new ZipException("Spanned archives are not currently handled");
+			}
+*/
+
+			entries = new ZipEntry[entriesForWholeCentralDir];
+			baseStream.Seek(offsetOfCentralDir, SeekOrigin.Begin);
+			
+			for (int i = 0; i < entriesForWholeCentralDir; i++) {
 				if (ReadLeInt() != ZipConstants.CENSIG) {
 					throw new ZipException("Wrong Central Directory signature");
 				}
 				
-				oldPos = baseStream.Position;
-				baseStream.Position += ZipConstants.CENHOW - ZipConstants.CENVEM;
+				int versionMadeBy      = ReadLeShort();
+				int versionToExtract   = ReadLeShort();
+				int bitFlags           = ReadLeShort();
+				int method             = ReadLeShort();
+				int dostime            = ReadLeInt();
+				int crc                = ReadLeInt();
+				int csize              = ReadLeInt();
+				int size               = ReadLeInt();
+				int nameLen            = ReadLeShort();
+				int extraLen           = ReadLeShort();
+				int commentLen         = ReadLeShort();
 				
-				if (baseStream.Position - oldPos != ZipConstants.CENHOW - ZipConstants.CENVEM) {
-					throw new EndOfStreamException();
-				}
-				int method = ReadLeShort();
-				int dostime = ReadLeInt();
-				int crc = ReadLeInt();
-				int csize = ReadLeInt();
-				int size = ReadLeInt();
-				int nameLen = ReadLeShort();
-				int extraLen = ReadLeShort();
-				int commentLen = ReadLeShort();
-				
-				oldPos = baseStream.Position;
-				baseStream.Position += ZipConstants.CENOFF - ZipConstants.CENDSK;
-				if (baseStream.Position - oldPos != ZipConstants.CENOFF - ZipConstants.CENDSK) {
-					throw new EndOfStreamException();
-				}
-				int offset = ReadLeInt();
+				int diskStartNo        = ReadLeShort();  // Not currently used
+				int internalAttributes = ReadLeShort();  // Not currently used
+
+				int externalAttributes = ReadLeInt();
+				int offset             = ReadLeInt();
 				
 				byte[] buffer = new byte[Math.Max(nameLen, commentLen)];
 				
 				baseStream.Read(buffer, 0, nameLen);
-				string name = ZipConstants.ConvertToString(buffer);
+				string name = ZipConstants.ConvertToString(buffer, nameLen);
 				
-				ZipEntry entry = new ZipEntry(name);
+				ZipEntry entry = new ZipEntry(name, versionToExtract, versionMadeBy);
 				entry.CompressionMethod = (CompressionMethod)method;
 				entry.Crc = crc & 0xffffffffL;
 				entry.Size = size & 0xffffffffL;
 				entry.CompressedSize = csize & 0xffffffffL;
 				entry.DosTime = (uint)dostime;
+				
 				if (extraLen > 0) {
 					byte[] extra = new byte[extraLen];
 					baseStream.Read(extra, 0, extraLen);
 					entry.ExtraData = extra;
 				}
+				
 				if (commentLen > 0) {
 					baseStream.Read(buffer, 0, commentLen);
-					entry.Comment = ZipConstants.ConvertToString(buffer);
+					entry.Comment = ZipConstants.ConvertToString(buffer, commentLen);
 				}
-				entry.zipFileIndex = i;
-				entry.offset = offset;
+				
+				entry.ZipFileIndex           = i;
+				entry.Offset                 = offset;
+				entry.ExternalFileAttributes = externalAttributes;
+				
 				entries[i] = entry;
 			}
 		}
 		
 		/// <summary>
-		/// Closes the ZipFile.  This also closes all input streams given by
-		/// this class.  After this is called, no further method should be
+		/// Closes the ZipFile.  This also closes all input streams managed by
+		/// this class.  Once closed, no further instance methods should be
 		/// called.
 		/// </summary>
-		/// <exception name="System.IO.IOException">
-		/// if a i/o error occured.
+		/// <exception cref="System.IO.IOException">
+		/// An i/o error occurs.
 		/// </exception>
 		public void Close()
 		{
@@ -285,8 +299,11 @@ namespace ICSharpCode.SharpZipLib.Zip
 		}
 		
 		/// <summary>
-		/// Returns an IEnumerator of all Zip entries in this Zip file.
+		/// Returns an enumerator for the Zip entries in this Zip file.
 		/// </summary>
+		/// <exception cref="InvalidOperationException">
+		/// The Zip file has been closed.
+		/// </exception>
 		public IEnumerator GetEnumerator()
 		{
 			if (entries == null) {
@@ -296,31 +313,59 @@ namespace ICSharpCode.SharpZipLib.Zip
 			return new ZipEntryEnumeration(entries);
 		}
 		
-		int GetEntryIndex(string name)
+		/// <summary>
+		/// Return the index of the entry with a matching name
+		/// </summary>
+		/// <param name="name">Entry name to find</param>
+		/// <param name="ignoreCase">If true the comparison is case insensitive</param>
+		/// <returns>The index position of the matching entry or -1 if not found</returns>
+		/// <exception cref="InvalidOperationException">
+		/// The Zip file has been closed.
+		/// </exception>
+		public int FindEntry(string name, bool ignoreCase)
 		{
+			if (entries == null) {
+				throw new InvalidOperationException("ZipFile has been closed");
+			}
+			
 			for (int i = 0; i < entries.Length; i++) {
-				if (name.Equals(entries[i].Name)) {
+				if (string.Compare(name, entries[i].Name, ignoreCase) == 0) {
 					return i;
 				}
 			}
 			return -1;
 		}
 		
+		/// <summary>
+		/// Indexer property for ZipEntries
+		/// </summary>
+		[System.Runtime.CompilerServices.IndexerNameAttribute("EntryByIndex")]
+		public ZipEntry this[int index] {
+			get {
+				return (ZipEntry) entries[index].Clone();	
+			}
+		}
+		
 		/// <summary>
 		/// Searches for a zip entry in this archive with the given name.
+		/// String comparisons are case insensitive
 		/// </summary>
 		/// <param name="name">
-		/// the name. May contain directory components separated by slashes ('/').
+		/// The name to find. May contain directory components separated by slashes ('/').
 		/// </param>
 		/// <returns>
-		/// the zip entry, or null if no entry with that name exists.
+		/// The zip entry, or null if no entry with that name exists.
 		/// </returns>
+		/// <exception cref="InvalidOperationException">
+		/// The Zip file has been closed.
+		/// </exception>
 		public ZipEntry GetEntry(string name)
 		{
 			if (entries == null) {
-				throw new InvalidOperationException("ZipFile has closed");
+				throw new InvalidOperationException("ZipFile has been closed");
 			}
-			int index = GetEntryIndex(name);
+			
+			int index = FindEntry(name, true);
 			return index >= 0 ? (ZipEntry) entries[index].Clone() : null;
 		}
 		
@@ -329,47 +374,53 @@ namespace ICSharpCode.SharpZipLib.Zip
 		/// central directory, and returns the offset to the data.
 		/// </summary>
 		/// <returns>
-		/// the start offset of the (compressed) data.
+		/// The start offset of the (compressed) data.
 		/// </returns>
-		/// <exception name="System.IO.IOException">
-		/// if a i/o error occured.
+		/// <exception cref="System.IO.EndOfStreamException">
+		/// The stream ends prematurely
 		/// </exception>
-		/// <exception name="ICSharpCode.SharpZipLib.ZipException">
-		/// if the local header doesn't match the central directory header
+		/// <exception cref="ICSharpCode.SharpZipLib.ZipException">
+		/// The local header signature is invalid, the entry and central header file name lengths are different
+		/// or the local and entry compression methods dont match
 		/// </exception>
 		long CheckLocalHeader(ZipEntry entry)
 		{
 			lock(baseStream) {
-				baseStream.Seek(entry.offset, SeekOrigin.Begin);
+				baseStream.Seek(entry.Offset, SeekOrigin.Begin);
 				if (ReadLeInt() != ZipConstants.LOCSIG) {
 					throw new ZipException("Wrong Local header signature");
 				}
 				
-				/* skip version and flags */
-				long oldPos = baseStream.Position;
-				baseStream.Position += ZipConstants.LOCHOW - ZipConstants.LOCVER;
-				if (baseStream.Position - oldPos != ZipConstants.LOCHOW - ZipConstants.LOCVER) {
-					throw new EndOfStreamException();
+				short shortValue = (short)ReadLeShort();     // version required to extract
+				if (shortValue > ZipConstants.VERSION_MADE_BY) {
+					throw new ZipException(string.Format("Version required to extract this entry not supported ({0})", shortValue));
+				}
+				
+				shortValue = (short)ReadLeShort();                  // general purpose bit flags.
+				if ((shortValue & 0x30) != 0) {
+					throw new ZipException("The library doesnt support the zip version required to extract this entry");
 				}
 				
 				if (entry.CompressionMethod != (CompressionMethod)ReadLeShort()) {
 					throw new ZipException("Compression method mismatch");
 				}
 				
-				/* Skip time, crc, size and csize */
-				oldPos = baseStream.Position;
+				// Skip time, crc, size and csize
+				long oldPos = baseStream.Position;
 				baseStream.Position += ZipConstants.LOCNAM - ZipConstants.LOCTIM;
 				
 				if (baseStream.Position - oldPos != ZipConstants.LOCNAM - ZipConstants.LOCTIM) {
 					throw new EndOfStreamException();
 				}
 				
-				if (entry.Name.Length != ReadLeShort()) {
+				// TODO make test more correct...  cant compare lengths as was done originally as this can fail for MBCS strings
+				int storedNameLength = ReadLeShort();
+				if (entry.Name.Length > storedNameLength) {
 					throw new ZipException("file name length mismatch");
 				}
 				
-				int extraLen = entry.Name.Length + ReadLeShort();
-				return entry.offset + ZipConstants.LOCHDR + extraLen;
+				int extraLen = storedNameLength + ReadLeShort();
+				return entry.Offset + ZipConstants.LOCHDR + extraLen;
 			}
 		}
 		
@@ -381,11 +432,14 @@ namespace ICSharpCode.SharpZipLib.Zip
 		/// <returns>
 		/// the input stream.
 		/// </returns>
-		/// <exception name="System.IO.IOException">
-		/// if a i/o error occured.
+		/// <exception cref="InvalidOperationException">
+		/// The ZipFile has already been closed
 		/// </exception>
-		/// <exception name="ICSharpCode.SharpZipLib.ZipException">
-		/// if the Zip archive is malformed.
+		/// <exception cref="ICSharpCode.SharpZipLib.ZipException">
+		/// The compression method for the entry is unknown
+		/// </exception>
+		/// <exception cref="IndexOutOfRangeException">
+		/// The entry is not found in the ZipFile
 		/// </exception>
 		public Stream GetInputStream(ZipEntry entry)
 		{
@@ -393,17 +447,42 @@ namespace ICSharpCode.SharpZipLib.Zip
 				throw new InvalidOperationException("ZipFile has closed");
 			}
 			
-			int index = entry.zipFileIndex;
+			int index = entry.ZipFileIndex;
 			if (index < 0 || index >= entries.Length || entries[index].Name != entry.Name) {
-				index = GetEntryIndex(entry.Name);
+				index = FindEntry(entry.Name, true);
 				if (index < 0) {
 					throw new IndexOutOfRangeException();
 				}
 			}
+			return GetInputStream(index);			
+		}
+		
+
+		/// <summary>
+		/// Creates an input stream reading the zip entry based on the index passed
+		/// </summary>
+		/// <returns>
+		/// An input stream.
+		/// </returns>
+		/// <exception cref="InvalidOperationException">
+		/// The ZipFile has already been closed
+		/// </exception>
+		/// <exception cref="ICSharpCode.SharpZipLib.ZipException">
+		/// The compression method for the entry is unknown
+		/// </exception>
+		/// <exception cref="IndexOutOfRangeException">
+		/// The entry is not found in the ZipFile
+		/// </exception>
+		public Stream GetInputStream(int entryIndex)
+		{
+			if (entries == null) {
+				throw new InvalidOperationException("ZipFile has closed");
+			}
+			
+			long start = CheckLocalHeader(entries[entryIndex]);
+			CompressionMethod method = entries[entryIndex].CompressionMethod;
+			Stream istr = new PartialInputStream(baseStream, start, entries[entryIndex].CompressedSize);
 			
-			long start = CheckLocalHeader(entries[index]);
-			CompressionMethod method = entries[index].CompressionMethod;
-			Stream istr = new PartialInputStream(baseStream, start, entries[index].CompressedSize);
 			switch (method) {
 				case CompressionMethod.Stored:
 					return istr;
@@ -415,19 +494,16 @@ namespace ICSharpCode.SharpZipLib.Zip
 		}
 		
 		/// <summary>
-		/// The comment for the whole zip file.
+		/// Gets the comment for the zip file.
 		/// </summary>
 		public string ZipFileComment {
 			get {
 				return comment;
 			}
-			set {
-				comment = value;
-			}
 		}
 		
 		/// <summary>
-		/// Returns the name of this zip file.
+		/// Gets the name of this zip file.
 		/// </summary>
 		public string Name {
 			get {
@@ -436,14 +512,17 @@ namespace ICSharpCode.SharpZipLib.Zip
 		}
 		
 		/// <summary>
-		/// Returns the number of entries in this zip file.
+		/// Gets the number of entries in this zip file.
 		/// </summary>
+		/// <exception cref="InvalidOperationException">
+		/// The Zip file has been closed.
+		/// </exception>
 		public int Size {
 			get {
-				try {
+				if (entries != null) {
 					return entries.Length;
-				} catch (Exception) {
-					throw new InvalidOperationException("ZipFile has closed");
+				} else {
+					throw new InvalidOperationException("ZipFile is closed");
 				}
 			}
 		}
@@ -502,7 +581,7 @@ namespace ICSharpCode.SharpZipLib.Zip
 			public override int ReadByte()
 			{
 				if (filepos == end) {
-					return -1;
+					return -1; //ok
 				}
 				
 				lock(baseStream) {
@@ -516,7 +595,7 @@ namespace ICSharpCode.SharpZipLib.Zip
 				if (len > end - filepos) {
 					len = (int) (end - filepos);
 					if (len == 0) {
-						return -1;
+						return 0;
 					}
 				}
 				lock(baseStream) {
