@@ -117,6 +117,11 @@ internal class DrawingControlWindow : DrawingWindow, IToolkitWindow
 		}
 	}
 
+	void IToolkitWindow.SendBeginInvoke(IntPtr i_gch)
+	{
+		StaticSendBeginInvoke(hwnd,i_gch);
+	}
+
 
 }; // class DrawingControlWindow
 
