@@ -650,6 +650,13 @@ public class Form : ContainerControl
 	// Create the toolkit window underlying this control.
 	internal override IToolkitWindow CreateToolkitWindow(IToolkitWindow parent)
 			{
+				// When a Form is reparented to a normal container control 
+				// which does work on Win32 unfortunately.
+				if(mdiParent == null && (!TopLevel))
+				{
+					return base.CreateToolkitWindow(parent);
+				}
+				
 				CreateParams cp = CreateParams;
 
 				// Create the window and set its initial caption.
@@ -704,6 +711,16 @@ public class Form : ContainerControl
 							 (screenSize.Height - cp.Height) / 2,
 							 window.Dimensions.Width, window.Dimensions.Height);
 				}
+				else if(formStartPosition == FormStartPosition.Manual)
+				{
+					window.MoveResize
+						(
+							cp.X,
+							cp.Y,
+							window.Dimensions.Width,
+							window.Dimensions.Height
+						);
+				}
 				return window;
 			}
 
@@ -712,7 +729,7 @@ public class Form : ContainerControl
 			{
 				get
 				{
-					return (mdiParent == null);
+					return ((mdiParent == null) && TopLevel);
 				}
 			}
 
@@ -1506,10 +1523,17 @@ public class Form : ContainerControl
 				get
 				{
 					int leftAdjust, topAdjust, rightAdjust, bottomAdjust;
-					ToolkitManager.Toolkit.GetWindowAdjust
-						(out leftAdjust, out topAdjust,
-						out rightAdjust, out bottomAdjust, GetFullFlags());
-					return new Point(leftAdjust, topAdjust);
+					if(FormBorderStyle != FormBorderStyle.None)
+					{
+						ToolkitManager.Toolkit.GetWindowAdjust
+							(out leftAdjust, out topAdjust,
+							out rightAdjust, out bottomAdjust, GetFullFlags());
+						return new Point(leftAdjust, topAdjust);
+					}
+					else
+					{
+						return Point.Empty;
+					}
 				}
 			}
 
