@@ -95,6 +95,8 @@ public class TextBox : TextBoxBase
 		textAlign = HorizontalAlignment.Left;
 
 		BackColor = SystemColors.Window;
+		ForeColor = SystemColors.WindowText;
+
 		// TODO Get this value from SystemInformation
 		CaretSetPosition(0);
 
@@ -183,7 +185,8 @@ public class TextBox : TextBoxBase
 	private void SetupScrollBars()
 	{
 		// Set vertical scrollbar
-		if (scrollBars == ScrollBars.Both || scrollBars == ScrollBars.Vertical)
+		// There is no vertical scrollbar if the textbox is not multiline
+		if (Multiline && (scrollBars == ScrollBars.Both || scrollBars == ScrollBars.Vertical))
 		{
 			if (vScrollBar == null)
 			{
@@ -201,8 +204,8 @@ public class TextBox : TextBoxBase
 			vScrollBar = null;
 		}
 		// Set horizontal scrollbar
-		// There is no scrollbar if the textbox is multiline
-		if ((scrollBars == ScrollBars.Both || scrollBars == ScrollBars.Horizontal))
+		// There is no hrizontal scrollbar if WordWrap is true
+		if (!WordWrap && (scrollBars == ScrollBars.Both || scrollBars == ScrollBars.Horizontal))
 		{
 			if (hScrollBar == null)
 			{
@@ -417,18 +420,36 @@ public class TextBox : TextBoxBase
 					y = currentY;
 				}
 			}
+			if(Text.Length != 0 && line == 0)
+			{
+				line++; // At least one line
+			}
 			string[] lines = new string[line];
 			int start = 0;
+			int i = 0;
 			line = 0;
 			// Break into strings
-			for (int i = 0; i < Text.Length; i++)
+			while(i < Text.Length)
 			{
 				if (Text[i] == '\r' && i < Text.Length - 1 && Text[i+1] == '\n') // Look for CRLF
 				{
 					lines[line++] = Text.Substring(start, i - start);
-					i+=2;
+					i+=2; 
 					start = i;
 				}
+				else
+				{
+					i+=1;
+				}
+			}
+
+			if(start < Text.Length)
+			{
+				lines[line++] = Text.Substring(start);
+			}
+			else if(start != 0 && start == Text.Length)
+			{
+				//FIXME: blank lines at end of text should be ""
 			}
 			
 			return lines;
@@ -436,10 +457,13 @@ public class TextBox : TextBoxBase
 		set
 		{
 			System.Text.StringBuilder sb = new System.Text.StringBuilder();
-			foreach(string s in Lines)
+			if(value != null)
 			{
-				sb.Append(s);
-				sb.Append("\r\n");
+				foreach(string s in value)
+				{
+					sb.Append(s);
+					sb.Append("\r\n");
+				}
 			}
 			SetTextActual( sb.ToString());
 			ResetView();
