@@ -34,6 +34,7 @@ using System.Xml.Schema;
 using System.Collections;
 
 namespace System.Xml.Serialization {
+#if CONFIG_SERIALIZATION
 	public class XmlSchemaImporter {
 
 		#region Fields
@@ -1636,4 +1637,5 @@ namespace System.Xml.Serialization {
 
 		#endregion // Methods
 	}
+#endif // CONFIG_SERIALIZATION
 }
