@@ -167,23 +167,6 @@ public abstract class Widget : Drawable, ICollection, IEnumerable
 				}
 			}
 
-	/// <summary>
-	/// <para>Destroy this drawable from a finalizer if it is
-	/// currently active.</para>
-	/// </summary>
-	///
-	/// <remarks>
-	/// <para>This version is called from object finalizers.  Subclasses
-	/// need to be careful not to lock the display during finalization
-	/// because doing so can lead to deadlock conditions.</para>
-	/// </remarks>
-	public override void DestroyFromFinalizer()
-			{
-				// Just clear the handle: the X server will clean
-				// up the window object for us at shutdown.
-				handle = XDrawable.Zero;
-			}
-
 	/// <summary>
 	/// <para>Get the X position of this widget relative to its parent.</para>
 	/// </summary>
@@ -1578,6 +1561,29 @@ public abstract class Widget : Drawable, ICollection, IEnumerable
 				return new Point(x, y);
 			}
 
+	protected void SendBeginInvoke(IntPtr i_gch)
+		{
+			XEvent xevent = new XEvent();
+			xevent.xany.type = (int)(EventType.ClientMessage);
+			xevent.xany.window = GetWidgetHandle();
+			xevent.xclient.format = 32;
+			xevent.xclient.setl(0,(int)i_gch);
+
+			try
+			{
+				IntPtr display = dpy.Lock();
+				xevent.xclient.message_type = Xlib.XInternAtom
+						(display, "INTERNAL_BEGIN_INVOKE", XBool.False);
+				Xlib.XSendEvent (display, GetWidgetHandle(),
+						XBool.False, (int)(EventMask.NoEventMask), ref xevent);
+				Xlib.XFlush(display);
+			}
+			finally
+			{
+				dpy.Unlock();
+			}
+	}
+
 } // class Widget
 
 } // namespace Xsharp
