@@ -552,15 +552,18 @@ public class Hashtable : ICloneable, ICollection, IDictionary, IEnumerable
 				}
 				else
 				{
-					int posn;
-					for(posn = 0; posn < table.Length; ++posn)
+					if(table != null)
 					{
-						if(table[posn].key != null && table[posn].key != removed)
+						int posn;
+						for(posn = 0; posn < table.Length; ++posn)
 						{
-							array.SetValue
-								(new DictionaryEntry(table[posn].key,
-													 table[posn].value),
-								 index++);
+							if(table[posn].key != null && table[posn].key != removed)
+							{
+								array.SetValue
+									(new DictionaryEntry(table[posn].key,
+														 table[posn].value),
+									 index++);
+							}
 						}
 					}
 				}
@@ -658,7 +661,7 @@ public class Hashtable : ICloneable, ICollection, IDictionary, IEnumerable
 				int count = capacity;
 				while(count > 0)
 				{
-					if(table[hash].key == null)
+					if(table[hash].key == null || table[hash].key == removed)
 					{
 						break;
 					}
@@ -703,7 +706,7 @@ public class Hashtable : ICloneable, ICollection, IDictionary, IEnumerable
 					int count = capacity;
 					while(count > 0)
 					{
-						if(table[hash].key == null)
+						if(table[hash].key == null || table[hash].key == removed)
 						{
 							break;
 						}
@@ -801,7 +804,7 @@ public class Hashtable : ICloneable, ICollection, IDictionary, IEnumerable
 				int count = capacity;
 				while(count > 0)
 				{
-					if(table[hash].key == null)
+					if(table[hash].key == null || table[hash].key == removed)
 					{
 						break;
 					}
