@@ -26,6 +26,9 @@ namespace System.Runtime.InteropServices
 
 [ComVisible(false)]
 [Serializable]
+#if CONFIG_FRAMEWORK_1_2
+[Obsolete("Use the class in System.Runtime.InteropServices.ComTypes instead")]
+#endif
 public enum TYPEKIND
 {
 	TKIND_ENUM      = 0,
