@@ -2,7 +2,7 @@
  * PaddingMode.cs - Implementation of the
  *		"System.Security.Cryptography.PaddingMode" class.
  *
- * Copyright (C) 2002  Southern Storm Software, Pty Ltd.
+ * Copyright (C) 2002, 2003  Southern Storm Software, Pty Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,9 +26,13 @@ namespace System.Security.Cryptography
 
 public enum PaddingMode
 {
-	None  = 1,
-	PKCS7 = 2,
-	Zeros = 3
+	None  		= 1,
+	PKCS7 		= 2,
+	Zeros 		= 3,
+#if CONFIG_FRAMEWORK_1_2
+	ANSIX923	= 4,
+	ISO10126	= 5
+#endif
 
 }; // enum PaddingMode
 
